@@ -107,7 +107,7 @@ class LoadTradeKline:
         previous_trade_id = None
         while since < unix_end:
             try:
-                trades = self.exchange.fetch_trades(symbol, since)
+                trades = self.exchange.fetch_trades(symbol, since, limit=1000)
 
                 if len(trades) == 0:
                     since += one_hour
@@ -132,7 +132,7 @@ class LoadTradeKline:
                         'price': trade['price'],
                         'amount': trade['amount'],
                     })
-                self.table.insert(result)
+                self.table.upsert(result)
                 time.sleep(int(self.exchange.rateLimit / 1000))
             except ccxt.NetworkError as e:
                 print(type(e).__name__, str(e))
