@@ -10,10 +10,10 @@ from notecoin.huobi.constant.system import (ApiVersion, HttpMethod,
 from notecoin.huobi.utils.api_signature import create_signature
 from notecoin.huobi.utils.huobi_api_exception import HuobiApiException
 from notecoin.huobi.utils.url_params_builder import UrlParamsBuilder
+from notetool.log import logger
 
 
 class RestApiSyncClient(object):
-
     def __init__(self, api_key=None, secret_key=None, url=None, *args, **kwargs):
         """
         Create the request client instance.
@@ -30,11 +30,7 @@ class RestApiSyncClient(object):
         self.__init_log = kwargs.get("init_log", None)
         self.__performance_test = kwargs.get("performance_test", None)
         if self.__init_log and self.__init_log:
-            logger = logging.getLogger("huobi-client")
-            logger.setLevel(level=logging.INFO)
-            handler = logging.StreamHandler()
-            handler.setFormatter(logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s'))
-            logger.addHandler(handler)
+            logger.addHandler(logging.StreamHandler())
 
     def request_process(self, method, url, params):
         if self.__performance_test is not None and self.__performance_test is True:
@@ -153,7 +149,6 @@ class RestApiSyncClient(object):
 
 
 class SubscribeClient(object):
-    # static property
     subscribe_watch_dog = WebSocketWatchDog()
 
     def __init__(self, api_key=None, secret_key=None, **kwargs):
@@ -171,11 +166,7 @@ class SubscribeClient(object):
         self.__uri = kwargs.get("url", WebSocketDefine.Uri)
         self.__init_log = kwargs.get("init_log", None)
         if self.__init_log and self.__init_log:
-            logger = logging.getLogger("huobi-client")
-            logger.setLevel(level=logging.INFO)
-            handler = logging.StreamHandler()
-            handler.setFormatter(logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s'))
-            logger.addHandler(handler)
+            logger.addHandler(logging.StreamHandler())
 
         self.__websocket_manage_list = list()
 
