@@ -1,4 +1,3 @@
-import json
 from time import sleep
 
 from notecoin.huobi.client import GenericClient
@@ -24,17 +23,18 @@ class FindNewCoin:
         self.symbol_dict = {}
 
     def init(self):
-        df = self.generic.get_exchange_symbols().data
-        self.symbol_df_last = self.symbol_df_now = df
-        symbols = df[['symbol', 'state']].values
-        for symbol, status in symbols:
-            self.symbol_dict[symbol] = status
+        data = self.generic.get_exchange_symbols().data
+        self.symbol_df_last = self.symbol_df_now = data
 
-    def update(self, df):
+        for _symbol in data:
+            symbol, state = _symbol['symbol'], _symbol['state']
+            self.symbol_dict[symbol] = state
+
+    def update(self, data):
         self.symbol_df_last = self.symbol_df_now
-        self.symbol_df_now = df
+        self.symbol_df_now = data
 
-        for _symbol in json.loads(df.to_json(orient="records")):
+        for _symbol in data:
             symbol, state = _symbol['symbol'], _symbol['state']
 
             if symbol not in self.symbol_dict.keys():
@@ -57,22 +57,27 @@ class FindNewCoin:
             self.msg_huobi.send_msg(f"buy new coin:{symbol}:{self.symbol_dict[symbol]}->{state}")
 
     def run(self):
+        step = 1
         self.init()
         while True:
             try:
-                df = self.generic.get_exchange_symbols().data
-                self.update(df)
+                data = self.generic.get_exchange_symbols().data
+                self.update(data)
                 unix = now2unix()
                 if unix - self.unix > 86400:
                     self.info()
                     self.unix = unix
 
                 if self.work_time.time_to_day_end(unix):
-                    sleep(0.1)
+                    sleep(0.2)
                 elif self.work_time.time_to_hour_end(unix):
-                    sleep(0.1)
-                elif self.work_time.time_to_ten_minute_end(unix):
                     sleep(0.5)
+                elif self.work_time.time_to_ten_minute_end(unix):
+                    sleep(1)
+                else:
+                    sleep(5)
+                # print(step)
+                step += 1
             except Exception as e:
                 print(e)
                 logger.info(f"error:{e}")
