@@ -1,6 +1,7 @@
 import time
 
-from notecoin.database.base import Base, BaseTable, create_all, session
+from notecoin.database.base import (Base, BaseTable, create_all,
+                                    create_session, session)
 from notecoin.okex.client.const import account_api
 from sqlalchemy import BIGINT, Column, Float, String
 
@@ -21,6 +22,8 @@ class OkexClientAccountBalance(Base, BaseTable):
     stgyEq = Column(Float(), comment='策略权益')
     updateTime = Column(BIGINT(), comment='记录更新时间')
 
+    #session = create_session()
+
     def __init__(self, *args, **kwargs):
         self.ccy = kwargs.get("ccy")
         self.eq = kwargs.get("eq", 0)
@@ -56,12 +59,10 @@ class OkexClientAccountBalance(Base, BaseTable):
 
             for detail in data:
                 session.merge(OkexClientAccountBalance(**detail))
-            session.flush()
             session.commit()
             return {"success": len(data)}
         except Exception as e:
             session.rollback()
-            session.commit()
             return {"update error": str(e), "res": res}
 
     @staticmethod
@@ -76,5 +77,4 @@ class OkexClientAccountBalance(Base, BaseTable):
             return {"delete success"}
         except Exception as e:
             session.rollback()
-            session.commit()
             return {"delete error": str(e)}
